@@ -38,7 +38,7 @@ import awkward.util
 
 def invert(permutation):
     permutation = permutation.reshape(-1)
-    out = awkward.util.numpy.zeros(permutation.max() + 1, dtype=awkward.util.INDEXTYPE)
+    out = awkward.util.numpy.zeros(permutation.max() + 1, dtype=IndexedArray.INDEXTYPE)
     identity = awkward.util.numpy.arange(len(permutation))
     out[permutation] = identity
     if not awkward.util.numpy.array_equal(out[permutation], identity):
@@ -104,7 +104,7 @@ class IndexedArray(awkward.array.base.AwkwardArrayWithContent):
 
     @index.setter
     def index(self, value):
-        value = awkward.util.toarray(value, awkward.util.INDEXTYPE, awkward.util.numpy.ndarray)
+        value = awkward.util.toarray(value, self.INDEXTYPE, awkward.util.numpy.ndarray)
         if not issubclass(value.dtype.type, awkward.util.numpy.integer):
             raise TypeError("index must have integer dtype")
         if (value < 0).any():
@@ -119,17 +119,17 @@ class IndexedArray(awkward.array.base.AwkwardArrayWithContent):
 
     @content.setter
     def content(self, value):
-        self._content = awkward.util.toarray(value, awkward.util.DEFAULTTYPE)
+        self._content = awkward.util.toarray(value, self.DEFAULTTYPE)
         self._isvalid = False
 
     def __len__(self):
         return len(self._index)
 
     def _gettype(self, seen):
-        return awkward.type._fromarray(self._content, seen)
-
-    def _getshape(self):
-        return self._index.shape
+        out = awkward.type._fromarray(self._content, seen)
+        for x in self._index.shape[:0:-1]:
+            out = awkward.type.ArrayType(x, out)
+        return out
 
     def _valid(self):
         if not self._isvalid:
@@ -214,176 +214,13 @@ class IndexedArray(awkward.array.base.AwkwardArrayWithContent):
         else:
             return self._content[self._index].pandas()
 
-class ByteIndexedArray(IndexedArray):
-    """
-    ByteIndexedArray
-    """
-
-    def __init__(self, index, content, dtype):
-        super(ByteIndexedArray, self).__init__(index, content)
-        self.dtype = dtype
-
-    def copy(self, index=None, content=None, dtype=None):
-        out = self.__class__.__new__(self.__class__)
-        out._index = self._index
-        out._content = self._content
-        out._dtype = self._dtype
-        if index is not None:
-            out.index = index
-        if content is not None:
-            out.content = content
-        if dtype is not None:
-            out.dtype = dtype
-        return out
-
-    def deepcopy(self, index=None, content=None, dtype=None):
-        out = self.copy(index=index, content=content)
-        out._index   = awkward.util.deepcopy(out._index)
-        out._content = awkward.util.deepcopy(out._content)
-        return out
-
-    def empty_like(self, **overrides):
-        mine = {}
-        mine["index"] = overrides.pop("index", self._index)
-        mine["content"] = overrides.pop("content", self._content)
-        mine["dtype"] = overrides.pop("dtype", self._dtype)
-        if isinstance(self._content, awkward.util.numpy.ndarray):
-            return self.copy(content=awkward.util.numpy.empty_like(self._content), **mine)
-        else:
-            return self.copy(content=self._content.empty_like(**overrides), **mine)
-
-    def zeros_like(self, **overrides):
-        mine = {}
-        mine["index"] = overrides.pop("index", self._index)
-        mine["content"] = overrides.pop("content", self._content)
-        mine["dtype"] = overrides.pop("dtype", self._dtype)
-        if isinstance(self._content, awkward.util.numpy.ndarray):
-            return self.copy(content=awkward.util.numpy.zeros_like(self._content), **mine)
-        else:
-            return self.copy(content=self._content.zeros_like(**overrides), **mine)
-
-    def ones_like(self, **overrides):
-        mine = {}
-        mine["index"] = overrides.pop("index", self._index)
-        mine["content"] = overrides.pop("content", self._content)
-        mine["dtype"] = overrides.pop("dtype", self._dtype)
-        if isinstance(self._content, awkward.util.numpy.ndarray):
-            return self.copy(content=awkward.util.numpy.ones_like(self._content), **mine)
-        else:
-            return self.copy(content=self._content.ones_like(**overrides), **mine)
-
-    def __awkward_persist__(self, ident, fill, prefix, suffix, schemasuffix, storage, compression, **kwargs):
-        self._valid()
-        return {"id": ident,
-                "call": ["awkward", self.__class__.__name__],
-                "args": [fill(self._index, self.__class__.__name__ + ".index", prefix, suffix, schemasuffix, storage, compression, **kwargs),
-                         fill(self._content, self.__class__.__name__ + ".content", prefix, suffix, schemasuffix, storage, compression, **kwargs),
-                         {"dtype": awkward.persist.dtype2json(self._dtype)}]}
-
-    @property
-    def content(self):
-        return self._content
-
-    @content.setter
-    def content(self, value):
-        self._content = awkward.util.toarray(value, awkward.util.CHARTYPE, awkward.util.numpy.ndarray).view(awkward.util.CHARTYPE).reshape(-1)
-
-    def _gettype(self, seen):
-        return self._dtype
-
-    def _getshape(self):
-        return self._index.shape
-
-    @property
-    def dtype(self):
-        return self._dtype
-
-    @dtype.setter
-    def dtype(self, value):
-        self._dtype = awkward.util.numpy.dtype(value)
-
-    def _valid(self):
-        if not self._isvalid:
-            if len(self._index) != 0 and self._index.reshape(-1).max() > len(self._content):
-                raise ValueError("maximum index ({0}) is beyond the length of the content ({1})".format(self._index.reshape(-1).max(), len(self._content)))
-
-            self._isvalid = True
-
-    def __iter__(self, checkiter=True):
-        if checkiter:
-            self._checkiter()
-        self._valid()
-        itemsize = self._dtype.itemsize
-        for i in self._index:
-            yield self._content[i : i + itemsize].view(self._dtype)[0]
-
-    def __getitem__(self, where):
-        self._valid()
-
-        if awkward.util.isstringslice(where):
-            raise IndexError("only integers, slices (`:`), and integer or boolean arrays are valid indices")
-
-        if isinstance(where, tuple) and len(where) == 0:
-            return self
-        if not isinstance(where, tuple):
-            where = (where,)
-        head, tail = where[:len(self._index.shape)], where[len(self._index.shape):]
-
-        if len(tail) != 0:
-            raise IndexError("too many indices for array")
-
-        starts = self._index[where]
-
-        if len(starts.shape) == 0:
-            if self._dtype.subdtype is None:
-                return self._content[starts : starts + self._dtype.itemsize].view(self._dtype)[0]
-            else:
-                dt, sh = self._dtype.subdtype
-                return self._content[starts : starts + self._dtype.itemsize].view(dt).reshape(sh)
-
-        else:
-            if len(starts) == 0:
-                return awkward.util.numpy.empty(0, dtype=self._dtype)
-
-            else:
-                index = awkward.util.numpy.repeat(starts, self._dtype.itemsize)
-                index += awkward.util.numpy.tile(awkward.util.numpy.arange(self._dtype.itemsize), len(starts))
-                if self._dtype.subdtype is None:
-                    return self._content[index].view(self._dtype)
-                else:
-                    dt, sh = self._dtype.subdtype
-                    return self._content[index].view(dt).reshape((-1,) + sh)
-
-    def __setitem__(self, where, what):
-        if awkward.util.isstringslice(where):
-            raise IndexError("only integers, slices (`:`), and integer or boolean arrays are valid indices")
-        else:
-            raise TypeError("invalid index for assigning column to Table: {0}".format(where))
-
-    def __delitem__(self, where):
-        if awkward.util.isstringslice(where):
-            raise IndexError("only integers, slices (`:`), and integer or boolean arrays are valid indices")
-        else:
-            raise TypeError("invalid index for removing column from Table: {0}".format(where))
-
-    def any(self):
-        return self._content[self._index].any()
-
-    def all(self):
-        return self._content[self._index].all()
-
-    @classmethod
-    def concat(cls, first, *rest):
-        raise NotImplementedError
-
-    def pandas(self):
-        raise NotImplementedError
-
 class SparseArray(awkward.array.base.AwkwardArrayWithContent):
     """
     SparseArray
     """
 
+    # TODO for 1.0: replace length with an indexshape
+
     def __init__(self, length, index, content, default=None):
         self.length = length
         self.index = index
@@ -479,7 +316,7 @@ class SparseArray(awkward.array.base.AwkwardArrayWithContent):
 
     @index.setter
     def index(self, value):
-        value = awkward.util.toarray(value, awkward.util.INDEXTYPE, awkward.util.numpy.ndarray)
+        value = awkward.util.toarray(value, self.INDEXTYPE, awkward.util.numpy.ndarray)
         if not issubclass(value.dtype.type, awkward.util.numpy.integer):
             raise TypeError("index must have integer dtype")
         if len(value.shape) != 1:
@@ -498,7 +335,7 @@ class SparseArray(awkward.array.base.AwkwardArrayWithContent):
 
     @content.setter
     def content(self, value):
-        self._content = awkward.util.toarray(value, awkward.util.DEFAULTTYPE)
+        self._content = awkward.util.toarray(value, self.DEFAULTTYPE)
         self._isvalid = False
 
     @property
@@ -525,9 +362,6 @@ class SparseArray(awkward.array.base.AwkwardArrayWithContent):
     def _gettype(self, seen):
         return awkward.type._fromarray(self._content, seen)
 
-    def _getshape(self):
-        return (self._length,)
-
     def __len__(self):
         return self._length
 
@@ -652,12 +486,12 @@ class SparseArray(awkward.array.base.AwkwardArrayWithContent):
             return self.copy(length=length, index=index, content=content)
 
         else:
-            head = awkward.util.toarray(head, awkward.util.INDEXTYPE)
+            head = awkward.util.toarray(head, self.INDEXTYPE)
             if len(head.shape) == 1 and issubclass(head.dtype.type, (awkward.util.numpy.bool, awkward.util.numpy.bool_)):
                 if self._length != len(head):
                     raise IndexError("boolean index did not match indexed array along dimension 0; dimension is {0} but corresponding boolean dimension is {1}".format(self._length, len(head)))
 
-                head = awkward.util.numpy.arange(self._length, dtype=awkward.util.INDEXTYPE)[head]
+                head = awkward.util.numpy.arange(self._length, dtype=self.INDEXTYPE)[head]
 
             if len(head.shape) == 1 and issubclass(head.dtype.type, awkward.util.numpy.integer):
                 mask = (head < 0)
@@ -670,8 +504,8 @@ class SparseArray(awkward.array.base.AwkwardArrayWithContent):
                 match[match >= len(self._index)] = len(self._index) - 1
                 explicit = (self._index[match] == head)
 
-                tags = awkward.util.numpy.zeros(len(head), dtype=awkward.util.TAGTYPE)
-                index = awkward.util.numpy.zeros(len(head), dtype=awkward.util.INDEXTYPE)
+                tags = awkward.util.numpy.zeros(len(head), dtype=self.TAGTYPE)
+                index = awkward.util.numpy.zeros(len(head), dtype=self.INDEXTYPE)
                 tags[explicit] = 1
                 index[explicit] = awkward.util.numpy.arange(awkward.util.numpy.count_nonzero(explicit))
 
@@ -684,7 +518,7 @@ class SparseArray(awkward.array.base.AwkwardArrayWithContent):
 
     def _getinverse(self):
         if self._inverse is None:
-            self._inverse = awkward.util.numpy.searchsorted(self._index, awkward.util.numpy.arange(self._length, dtype=awkward.util.INDEXTYPE), side="left")
+            self._inverse = awkward.util.numpy.searchsorted(self._index, awkward.util.numpy.arange(self._length, dtype=self.INDEXTYPE), side="left")
             if len(self._index) > 0:
                 self._inverse[self._index[-1] + 1 :] = len(self._index) - 1
         return self._inverse
@@ -710,9 +544,9 @@ class SparseArray(awkward.array.base.AwkwardArrayWithContent):
             return awkward.util.numpy.empty(0, dtype=awkward.util.numpy.bool_)
 
         if maskedwhen:
-            return self._index[self._getinverse()] == awkward.util.numpy.arange(self._length, dtype=awkward.util.INDEXTYPE)
+            return self._index[self._getinverse()] == awkward.util.numpy.arange(self._length, dtype=self.INDEXTYPE)
         else:
-            return self._index[self._getinverse()] != awkward.util.numpy.arange(self._length, dtype=awkward.util.INDEXTYPE)
+            return self._index[self._getinverse()] != awkward.util.numpy.arange(self._length, dtype=self.INDEXTYPE)
 
     def _invert(self, what):
         if len(what) != self._length:
