@@ -40,23 +40,6 @@ class MaskedArray(awkward.array.base.AwkwardArrayWithContent):
     MaskedArray
     """
 
-    ### WTF were the designers of numpy.ma thinking?
-    # @staticmethod
-    # def is_masked(x):
-    #     return awkward.util.numpy.ma.is_masked(x)
-    # masked = awkward.util.numpy.ma.masked
-
-    @staticmethod
-    def is_masked(x):
-        if isinstance(x, MaskedArray):
-            # numpy.ma.is_masked(array) if any element is masked
-            if x.maskedwhen:
-                return x.mask.any()
-            else:
-                return not x.mask.all()
-        else:
-            # numpy.ma.is_masked(x) if x represents a masked constant
-            return x is MaskedArray.masked
     masked = None
 
     def __init__(self, mask, content, maskedwhen=True):
@@ -124,7 +107,7 @@ class MaskedArray(awkward.array.base.AwkwardArrayWithContent):
 
     @mask.setter
     def mask(self, value):
-        value = awkward.util.toarray(value, awkward.util.MASKTYPE, awkward.util.numpy.ndarray)
+        value = awkward.util.toarray(value, self.MASKTYPE, awkward.util.numpy.ndarray)
         if len(value.shape) != 1:
             raise ValueError("mask must have 1-dimensional shape")
         if not issubclass(value.dtype.type, (awkward.util.numpy.bool_, awkward.util.numpy.bool)):
@@ -132,19 +115,29 @@ class MaskedArray(awkward.array.base.AwkwardArrayWithContent):
         self._mask = value
         self._isvalid = False
 
-    def boolmask(self, maskedwhen=True):
+    def boolmask(self, maskedwhen=None):
+        if maskedwhen is None:
+            maskedwhen = self._maskedwhen
         if maskedwhen == self._maskedwhen:
             return self._mask
         else:
             return awkward.util.numpy.logical_not(self._mask)
 
+    @property
+    def ismasked(self):
+        return self.boolmask(maskedwhen=True)
+
+    @property
+    def isunmasked(self):
+        return self.boolmask(maskedwhen=False)
+
     @property
     def content(self):
         return self._content
 
     @content.setter
     def content(self, value):
-        self._content = awkward.util.toarray(value, awkward.util.DEFAULTTYPE)
+        self._content = awkward.util.toarray(value, self.DEFAULTTYPE)
         self._isvalid = False
 
     @property
@@ -159,10 +152,7 @@ class MaskedArray(awkward.array.base.AwkwardArrayWithContent):
         return len(self._mask)
 
     def _gettype(self, seen):
-        return awkward.type._fromarray(self._content, seen)
-
-    def _getshape(self):
-        return (len(self._mask),)
+        return awkward.type.OptionType(awkward.type._fromarray(self._content, seen))
 
     def _valid(self):
         if not self._isvalid:
@@ -260,7 +250,7 @@ class MaskedArray(awkward.array.base.AwkwardArrayWithContent):
         result = getattr(ufunc, method)(*inputs, **kwargs)
 
         # put the masked out values back
-        index = awkward.util.numpy.full(len(tokeep), -1, dtype=awkward.util.INDEXTYPE)
+        index = awkward.util.numpy.full(len(tokeep), -1, dtype=self.INDEXTYPE)
         index[tokeep] = awkward.util.numpy.arange(awkward.util.numpy.count_nonzero(tokeep))
 
         if isinstance(result, tuple):
@@ -271,7 +261,7 @@ class MaskedArray(awkward.array.base.AwkwardArrayWithContent):
             return awkward.array.objects.Methods.maybemixin(type(result), IndexedMaskedArray)(index, result, maskedwhen=-1)
 
     def indexed(self):
-        maskindex = awkward.util.numpy.arange(len(self), dtype=awkward.util.INDEXTYPE)
+        maskindex = awkward.util.numpy.arange(len(self), dtype=self.INDEXTYPE)
         maskindex[self.boolmask(maskedwhen=True)] = -1
         return IndexedMaskedArray(maskindex, self._content, maskedwhen=-1)
 
@@ -293,6 +283,8 @@ class BitMaskedArray(MaskedArray):
     BitMaskedArray
     """
 
+    # TODO for 1.0: need a maskshape parameter to apply length and multidimensional shape to the output
+
     def __init__(self, mask, content, maskedwhen=True, lsborder=False):
         super(BitMaskedArray, self).__init__(mask, content, maskedwhen=maskedwhen)
         self.lsborder = lsborder
@@ -329,18 +321,15 @@ class BitMaskedArray(MaskedArray):
 
     @mask.setter
     def mask(self, value):
-        value = awkward.util.toarray(value, awkward.util.BITMASKTYPE, awkward.util.numpy.ndarray)
+        value = awkward.util.toarray(value, self.BITMASKTYPE, awkward.util.numpy.ndarray)
         if len(value.shape) != 1:
             raise ValueError("mask must have 1-dimensional shape")
-        self._mask = value.view(awkward.util.BITMASKTYPE)
+        self._mask = value.view(self.BITMASKTYPE)
         self._isvalid = False
 
     def __len__(self):
         return len(self._content)
 
-    def _getshape(self):
-        return self._content.shape
-
     @staticmethod
     def _ceildiv8(x):
         return -(-x >> 3)   # this is int(math.ceil(x / 8))
@@ -350,11 +339,11 @@ class BitMaskedArray(MaskedArray):
         out = awkward.util.numpy.unpackbits(bitmask)
         if lsborder:
             out = out.reshape(-1, 8)[:,::-1].reshape(-1)
-        return out.view(awkward.util.MASKTYPE)
+        return out.view(MaskedArray.MASKTYPE)
         
     @staticmethod
     def bool2bit(boolmask, lsborder=False):
-        boolmask = awkward.util.toarray(boolmask, awkward.util.MASKTYPE, awkward.util.numpy.ndarray)
+        boolmask = awkward.util.toarray(boolmask, MaskedArray.MASKTYPE, awkward.util.numpy.ndarray)
         if len(boolmask.shape) != 1:
             raise ValueError("boolmask must have 1-dimensional shape")
         if not issubclass(boolmask.dtype.type, (awkward.util.numpy.bool_, awkward.util.numpy.bool)):
@@ -378,7 +367,9 @@ class BitMaskedArray(MaskedArray):
 
         return awkward.util.numpy.packbits(out)
 
-    def boolmask(self, maskedwhen=True):
+    def boolmask(self, maskedwhen=None):
+        if maskedwhen is None:
+            maskedwhen = self._maskedwhen
         if maskedwhen == self._maskedwhen:
             bitmask = self._mask
         else:
@@ -451,9 +442,9 @@ class BitMaskedArray(MaskedArray):
             bitmask = awkward.util.numpy.right_shift(128, bitpos)
 
         if isinstance(bitmask, awkward.util.numpy.ndarray):
-            bitmask = bitmask.astype(awkward.util.BITMASKTYPE)
+            bitmask = bitmask.astype(self.BITMASKTYPE)
         else:
-            bitmask = awkward.util.BITMASKTYPE.type(bitmask)
+            bitmask = self.BITMASKTYPE.type(bitmask)
 
         return bytepos, bitmask
 
@@ -475,7 +466,7 @@ class BitMaskedArray(MaskedArray):
         
             elif len(where.shape) == 1 and issubclass(where.dtype.type, (awkward.util.numpy.bool, awkward.util.numpy.bool_)):
                 # scales with the size of the mask anyway, so go ahead and unpack the whole mask
-                unpacked = awkward.util.numpy.unpackbits(self._mask).view(awkward.util.MASKTYPE)
+                unpacked = awkward.util.numpy.unpackbits(self._mask).view(self.MASKTYPE)
 
                 if self._lsborder:
                     unpacked = unpacked.reshape(-1, 8)[:,::-1].reshape(-1)[:len(where)]
@@ -531,6 +522,8 @@ class IndexedMaskedArray(MaskedArray):
     IndexedMaskedArray
     """
 
+    # TODO for 1.0: remove maskedwhen and instead check for any negative value (can't be allowed to inherit methods that assume self.maskedwhen!)
+
     def __init__(self, mask, content, maskedwhen=-1):
         super(IndexedMaskedArray, self).__init__(mask, content, maskedwhen=maskedwhen)
         self._isvalid = False
@@ -563,7 +556,7 @@ class IndexedMaskedArray(MaskedArray):
 
     @mask.setter
     def mask(self, value):
-        value = awkward.util.toarray(value, awkward.util.INDEXTYPE, awkward.util.numpy.ndarray)
+        value = awkward.util.toarray(value, self.INDEXTYPE, awkward.util.numpy.ndarray)
         if not issubclass(value.dtype.type, awkward.util.numpy.integer):
             raise TypeError("starts must have integer dtype")
         if len(value.shape) != 1:
@@ -577,7 +570,7 @@ class IndexedMaskedArray(MaskedArray):
 
     @content.setter
     def content(self, value):
-        self._content = awkward.util.toarray(value, awkward.util.DEFAULTTYPE)
+        self._content = awkward.util.toarray(value, self.DEFAULTTYPE)
         self._isvalid = False
 
     @property
@@ -591,6 +584,8 @@ class IndexedMaskedArray(MaskedArray):
         self._maskedwhen = value
 
     def boolmask(self, maskedwhen=True):
+        if maskedwhen is None:
+            raise TypeError("maskedwhen must be True or False")
         if maskedwhen:
             return self._mask == self._maskedwhen
         else:
