@@ -378,6 +378,9 @@ def deserialize(storage, name="", whitelist=whitelist, cache=None):
         schema = schema.decode("ascii")
     schema = json.loads(schema)
 
+    if "awkward" not in schema:
+        raise ValueError("JSON object is not an awkward-array schema (missing 'awkward' field)")
+
     prefix = schema.get("prefix", "")
     seen = {}
 
@@ -400,11 +403,6 @@ def deserialize(storage, name="", whitelist=whitelist, cache=None):
                 if "kwargs" in schema:
                     kwargs.update({n: unfill(x) for n, x in schema["kwargs"].items()})
 
-                if "*" in schema:
-                    args = args + [unfill(x) for x in schema["*"]]
-                if "**" in schema:
-                    kwargs.update({n: unfill(x) for n, x in schema["**"].items()})
-
                 out = gen(*args, **kwargs)
 
             elif "read" in schema:
@@ -419,12 +417,12 @@ def deserialize(storage, name="", whitelist=whitelist, cache=None):
             elif "tuple" in schema:
                 out = tuple(unfill(x) for x in schema["tuple"])
 
-            elif "pairs" in schema:
-                out = [(n, unfill(x)) for n, x in schema["pairs"]]
-
             elif "dict" in schema:
                 out = {n: unfill(x) for n, x in schema["dict"].items()}
 
+            elif "pairs" in schema:
+                out = [(n, unfill(x)) for n, x in schema["pairs"]]
+
             elif "dtype" in schema:
                 out = json2dtype(schema["dtype"])
 
@@ -500,13 +498,13 @@ def keys(storage, name="", subschemas=True):
                     for y in recurse(x):
                         yield y
 
-            elif "pairs" in schema:
-                for n, x in schema["pairs"]:
+            elif "dict" in schema:
+                for x in schema["dict"].values():
                     for y in recurse(x):
                         yield y
 
-            elif "dict" in schema:
-                for x in schema["dict"].values():
+            elif "pairs" in schema:
+                for n, x in schema["pairs"]:
                     for y in recurse(x):
                         yield y
 
